<?php
defined( 'STM_ACTIVATION_URL' ) || define( 'STM_ACTIVATION_URL', 'https://support.stylemixthemes.com/theme-activation?envatoId=%s&site=%s' );
defined( 'STM_LICENSE_API_URL' ) || define( 'STM_LICENSE_API_URL', 'https://license.stylemixthemes.com' );

add_action( 'admin_init', 'stm_theme_handle_activation_token' );
add_action( 'admin_init', 'stm_theme_init_check_activated' );
add_action( 'admin_init', 'stm_theme_handle_deactivation' );
add_action( 'wp_ajax_consulting_install_plugin', 'consulting_install_plugin' );
add_action( 'wp_ajax_stm_reset_demo', 'stm_theme_reset_demo' );

if ( is_admin() ) {
	require_once __DIR__ . '/review-notice.php';
	require_once __DIR__ . '/admin_screens.php';
}

/*Redirect to theme Welcome screen*/
function stm_theme_init_check_activated() {
	global $pagenow;

	if ( is_admin() && 'themes.php' == $pagenow && isset( $_GET['activated'] ) && ! defined( 'ENVATO_HOSTED_SITE' ) ) {
		wp_redirect( admin_url( "admin.php?page=stm-admin" ) );
	}
}

/*Theme info*/
function stm_theme_get_info() {
	$theme = wp_get_theme();
	$theme_name = $theme->get('Name');
	$theme_v = $theme->get('Version');

	$theme_info = array(
		'name' => $theme_name,
		'slug' => sanitize_file_name(strtolower($theme_name)),
		'v'    => $theme_v,
	);

	return $theme_info;
}

function stm_theme_activation_url() {
	return sprintf( STM_ACTIVATION_URL, STM_ENVATO_ID, site_url() );
}

function stm_theme_activation_info() {
	return get_site_option( STM_TOKEN_OPTION );
}

function stm_theme_activation_token() {
	$token_info = stm_theme_activation_info();
	return '798af5ec-37694bca-8b5944cd-3a583792';
}

function stm_theme_check_token() {
	$token = stm_theme_activation_token();
	
	$activated = true;

	

	return true;
}

function stm_theme_handle_activation_token() {
	if ( isset( $_GET['stylemixthemes-token'] ) && current_user_can( 'manage_options' ) ) {
		$token = '798af5ec-37694bca-8b5944cd-3a583792';
		$return = _stm_theme_downloads_api_request( 'GET', 'check', compact( 'token' ) );
		
			set_site_transient( STM_TOKEN_CHECKED_OPTION, true, DAY_IN_SECONDS );
			delete_site_transient( 'stm_auth_notice' );
			update_site_option( STM_TOKEN_OPTION, $return );
		

		wp_safe_redirect( admin_url( 'admin.php?page=stm-admin' ) );
		exit;
	}
}

function stm_theme_handle_deactivation() {
	if ( isset( $_POST['action'] ) && $_POST['action'] == 'stm-deactivate' && current_user_can( 'manage_options' ) ) {
		_stm_theme_downloads_api_request( 'DELETE', 'deactivate' );
		delete_site_transient( STM_TOKEN_CHECKED_OPTION );
		delete_site_transient( 'stm_auth_notice' );

		if ( ! stm_theme_dev_mode() ) {
			/** @var \WP_Filesystem_Base $wp_filesystem */
			global $wp_filesystem;
			if ( empty( $wp_filesystem ) ) {
				require_once ABSPATH . '/wp-admin/includes/file.php';
				WP_Filesystem();
			}
			$wp_filesystem->delete( get_template_directory(), true );
		}

		wp_safe_redirect( admin_url() );
		exit;
	}
}

function _stm_theme_downloads_api_request( $method, $path, $options = [] ) {
	$options = wp_parse_args( $options, [
		'token' => stm_theme_activation_token(),
	] );
	$res = wp_remote_request( STM_LICENSE_API_URL . '/' . ltrim( $path, '/' ), [
		'method' => $method,
		'headers' => [
			'Accept' => 'application/json',
			'Authorization' => 'Bearer ' . $options['token'],
            'X-Wordpress-Site' => get_site_url(),
            'X-Stylemix-Item' => get_template(),
		],
	] );

	
	$code   = wp_remote_retrieve_response_code( $res );
	$return = json_decode( wp_remote_retrieve_body( $res ), true );

	
	return $return;
}

/**
 * Filter is used to convert abstract download url to final physical url using activation token.
 * @see \WP_Upgrader::run()
 */
add_filter( 'upgrader_package_options', function ( $options ) {
	// this is not our case
	if ( ! isset( $options['package'] ) || strpos( $options['package'], 'downloads://' ) !== 0 ) {
		return $options;
	}

	$token = stm_theme_activation_token();

	
	$file = str_replace( 'downloads://', '', $options['package'] );
	$res = wp_remote_get( sprintf( STM_LICENSE_API_URL . '/download-url?file=%s' , $file ), [
		'headers' => [
			'Authorization' => 'Bearer ' . $token,
			'X-Wordpress-Site' => get_site_url(),
			'X-Stylemix-Item' => get_template(),
		],
	] );

	$code = wp_remote_retrieve_response_code( $res );
	$body = wp_remote_retrieve_body( $res );
	if ( $code === 200) {
		$options['package'] = $body;
	}
	elseif ( is_wp_error( $res ) ) {
		$options['package'] = $res;
	}
	else {
		$json = json_decode( $body, true );
		$options['package'] = new WP_Error(
			$code,
			! empty( $json['message'] ) ? $json['message'] : "HTTP error occurred with status: $code and no message while resolving download URL."
		);
	}

	return $options;
} );

/**
 * Used to abort download if there is an error occurred.
 * @see \WP_Upgrader::download_package()
 */
add_filter( 'upgrader_pre_download', function ( $res, $package ) {
	if ( is_wp_error( $package ) ) {
		return $package;
	}

	return $res;
}, 10, 2 );

function stm_theme_dev_mode() {
	return true;
}

function stm_convert_memory($size) {
	$l   = substr( $size, -1 );
	$ret = substr( $size, 0, -1 );
	switch ( strtoupper( $l ) ) {
		case 'P':
			$ret *= 1024;
		case 'T':
			$ret *= 1024;
		case 'G':
			$ret *= 1024;
		case 'M':
			$ret *= 1024;
		case 'K':
			$ret *= 1024;
	}
	return $ret;
}

function stm_get_admin_images_url($image) {
	return esc_url(get_template_directory_uri() . '/assets/admin/images/' . $image);
}

function stm_theme_reset_demo() {
	global $wpdb;

	check_ajax_referer('stm_reset_demo', 'nonce');

	$wpdb->query( "TRUNCATE TABLE $wpdb->posts" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->postmeta" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->comments" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->commentmeta" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->terms" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->termmeta" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->term_taxonomy" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->term_relationships" );
	$wpdb->query( "TRUNCATE TABLE $wpdb->links" );

	update_option( 'show_on_front', 'posts' );

	// Delete Sliders
	consulting_delete_all_revolution_sliders();

	// Delete Widgets
	delete_option( 'sidebars_widgets' );

	// Delete Theme Options
	delete_option( 'consulting_layout' );
	delete_option( 'theme_mods_consulting' );
	delete_option( 'plugins_mods_consulting' );
	delete_option( 'stm_hb_settings' );

	// Deactivate Plugins
	$required_plugins   = consulting_require_plugins(true);
	$plugins            = [];

	foreach ( $required_plugins as $plugin ) {
		$plugins[] = consulting_get_plugin_main_path( $plugin['slug'] );
	}

	deactivate_plugins( $plugins );

	wp_send_json( esc_html__('Database was reset successfully!', 'consulting') );
}

/*Plugin installer via tgmpa*/
function consulting_install_plugin() {
    check_ajax_referer('consulting_install_plugin', 'security');
    $r = array();
    $plugins = consulting_require_plugins(true);
    $layout = sanitize_text_field($_GET['layout']);
    $builder = sanitize_text_field($_GET['builder']);
    $layout_plugins_config = consulting_layout_plugins($layout);
    if(!empty($builder)) {
        $layout_plugins_config[] = $builder;
        if($builder === 'elementor') $layout_plugins_config[] = 'consulting-elementor-widgets';
    }
    $layout_plugins = array();

    foreach($plugins as $plugin_name => $plugin_info) {
        if(in_array($plugin_name, $layout_plugins_config)) {
            $layout_plugins[$plugin_name] = $plugin_info;
        }
    }

    $plugins = $layout_plugins;

    $plugin_slug = sanitize_text_field($_GET['plugin']);

    if (!current_user_can('install_plugins')) {
        return;
    }

    /*if install demo*/
    if($plugin_slug === 'import_demo') {
        $r['import_demo'] = true;
        wp_send_json($r);
    }

    /*No plugin*/
    if (empty($plugin_slug) and !empty($plugins[$plugin_slug])) {
        wp_send_json(array('error' => esc_html__('Error occured', 'consulting')));
        exit;
    }

    require_once ABSPATH . 'wp-load.php';
    require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
    require_once ABSPATH . 'wp-admin/includes/class-plugin-upgrader.php';
    require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
    require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader-skin.php';
    require_once get_template_directory() . '/admin/includes/stm_upgrader_skin.php';


    $plugin_upgrader = new Plugin_Upgrader(new STM_Plugin_Upgrader_Skin(array('plugin' => $plugin_slug)));
    $plugin_info = $plugins[$plugin_slug];
    $next = consulting_get_next($plugins, $plugin_slug);


    if (!empty($plugin_info['source'])) {
        $source = $plugin_info['source'];
    } else {
        $response = plugins_api('plugin_information', array('slug' => $plugin_slug));
        if(!is_wp_error($response) and !empty($response->download_link)) {
            $source = $response->download_link;
        }
    };

    $r['source'] = $source;

    if(!empty($source)) {
        $installed = (consulting_check_plugin_active($plugin_slug)) ? true : $plugin_upgrader->install($source);
        if(is_wp_error($installed)) {
            $r['error'] = $installed->get_error_message();
        } else {
            if(!empty($next)) {
                $r['next'] = $next['slug'];
            }
            consulting_activate_plugin($plugin_slug);
            $r['installed'] = true;
            $r['activated'] = true;
            $r['plugin_slug'] = $plugin_slug;
        }
    }

    /*Check if last*/
    if(end($plugins) === $plugin_info) $r['import_demo'] = true;

    wp_send_json($r);
    exit;
}

function consulting_check_plugin_active($slug) {
    /*if just slug*/
    if(strpos($slug, '.php') === false) $slug = consulting_get_plugin_main_path($slug);
    return in_array($slug, (array)get_option('active_plugins', array())) || is_plugin_active_for_network($slug);
}

function consulting_activate_plugin($slug) {
    activate_plugin(consulting_get_plugin_main_path($slug));
}

function consulting_get_plugin_main_path($slug) {
    $plugin_data = get_plugins('/' . $slug);
    if(!empty($plugin_data)) {
        $plugin_file = array_keys($plugin_data);
        $plugin_path = $slug . '/' . $plugin_file[0];
    } else {
        $plugin_path = false;
    }
    return $plugin_path;
}

function consulting_get_next($array, $key)
{
    $currentKey = key($array);
    while ($currentKey !== null && $currentKey != $key) {
        next($array);
        $currentKey = key($array);
    }
    return next($array);
}

/**
 * Return secondary required Plugins
 * @return array
 */
function consulting_secondary_required_plugins() {
	$plugins = [
		'js_composer',
		'elementor',
		'consulting-elementor-widgets',
		'pearl-header-builder'
	];
	return $plugins;
}

/**
 * Delete all Revolution Sliders
 * @return bool
 */
function consulting_delete_all_revolution_sliders() {
	if ( class_exists('RevSlider') ) {
		$rev_slider = new RevSlider();
		$sliders    = $rev_slider->get_sliders();
		foreach ( $sliders as $slider ) {
			$slider->delete_slider();
		}
	}
	return true;
}
