<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit( 'Direct script access denied.' );
}

/**
 * Class STM_Import_CLI
 */
class STM_Import_CLI {

	/**
	 * Import Demo Content.
	 *
	 * ## OPTIONS
	 *
	 * <layout>
	 * : Layout Slug.
	 *
	 * [--builder=<builder>]
	 * : Choose Builder.
	 * ---
	 * default: js_composer
	 * options:
	 *   - js_composer
	 *   - elementor
	 * ---
	 *
	 * [--data=<theme_options,content,widgets>]
	 * : Choose Data to Import. Default: All.
	 *
	 * [--no-media]
	 * : Don't import media Attachments.
	 *
	 * ## EXAMPLES
	 *
	 *     wp stm import layout_1 --builder=elementor
	 *
	 * @when after_wp_load
	 */
	public function import( $args, $assoc_args ) {
		list( $layout ) = $args;
		$builder        = ( ! empty( $assoc_args['builder'] ) ) ? $assoc_args['builder'] : 'js_composer';
		$import_media   = empty($assoc_args['no-media']);
		$import_data    = [
			'theme_options',
			'content',
			'widgets'
		];

		if ( ! empty( $assoc_args['data'] ) ) {
			$import_data = explode(',', $assoc_args['data']);
		}

		if ( function_exists('stm_demo_import_content_cli') ) {
			foreach ( $import_data as $data) {
				stm_demo_import_content_cli( $layout, $builder, $data, $import_media );
				WP_CLI::success( "'$data' import done!"  );
			}

			// Finish Demo Import
			stm_demo_import_content_cli( $layout, $builder, '', $import_media );
			WP_CLI::success( 'Import finished!' );
		} else {
			WP_CLI::error( 'Import function not found!' );
		}
	}

	/**
	 * Install Layout Plugins.
	 *
	 * ## OPTIONS
	 *
	 * <layout>
	 * : Layout Slug.
	 *
	 * [--builder=<builder>]
	 * : Choose Builder.
	 * ---
	 * default: js_composer
	 * options:
	 *   - js_composer
	 *   - elementor
	 * ---
	 *
	 * ## EXAMPLES
	 *
	 *     wp stm install layout_1 --builder=elementor
	 *
	 * @when after_wp_load
	 */
	public function install( $args, $assoc_args ) {
		list( $layout )     = $args;
		$plugins            = consulting_require_plugins(true);
		$builder            = ( ! empty( $assoc_args['builder'] ) ) ? $assoc_args['builder'] : 'js_composer';
		$layout_plugins     = consulting_layout_plugins($layout);
		$layout_plugins[]   = $builder;

		if ( $builder === 'elementor' ) {
			$layout_plugins[] = 'consulting-elementor-widgets';
		}

		// Load required files
		require_once ABSPATH . 'wp-load.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader.php';
		require_once ABSPATH . 'wp-admin/includes/class-plugin-upgrader.php';
		require_once ABSPATH . 'wp-admin/includes/plugin-install.php';
		require_once ABSPATH . 'wp-admin/includes/plugin.php';
		require_once ABSPATH . 'wp-admin/includes/class-wp-upgrader-skin.php';
		require_once get_template_directory() . '/admin/includes/stm_upgrader_skin.php';

		foreach($layout_plugins as $plugin_slug) {
			$plugin_upgrader    = new Plugin_Upgrader(new STM_Plugin_Upgrader_Skin(array('plugin' => $plugin_slug)));
			$plugin_info        = $plugins[$plugin_slug];

			if ( !empty($plugin_info['source']) ) {
				$source = $plugin_info['source'];
			} else {
				$response = plugins_api('plugin_information', array('slug' => $plugin_slug));
				if ( !is_wp_error($response) and !empty($response->download_link)) {
					$source = $response->download_link;
				}
			};

			if ( !empty($source) ) {
				$installed = (consulting_check_plugin_active($plugin_slug)) ? true : $plugin_upgrader->install($source);
				if ( is_wp_error($installed) ) {
					WP_CLI::error( $installed->get_error_message() );
				} else {
					consulting_activate_plugin($plugin_slug);
					WP_CLI::success( "{$plugin_info['name']} plugin installed & activated!" );
				}
			}
		}

		WP_CLI::success( "Installation process finished!" );
	}
}

WP_CLI::add_command( 'stm', 'STM_Import_CLI' );