<?php

/**
 * Apply Filter Post Meta
 */
add_filter( 'stm_wp_import_post_meta', 'stm_wp_import_post_meta_filter', 10, 1 );

function stm_wp_import_post_meta_filter( $post_meta ) {
	if ( function_exists('consulting_importer_get_placeholder') && !empty( consulting_importer_get_placeholder() ) ) {
		foreach ( $post_meta as $meta_index => $meta ) {
			switch ( $meta['key'] ) {
				case '_elementor_data':
					consulting_import_rebuilder_elementor_data($post_meta[ $meta_index ]['value'] );
					break;
				case 'testimonial_bg_img':
					$post_meta[ $meta_index ]['value']  = consulting_importer_get_placeholder();
					break;
				case 'title_box_bg_image':
					if ( ! empty( $meta['value'] ) ) {
						$post_meta[ $meta_index ]['value']  = consulting_importer_get_placeholder();
					}
					break;
			}

		}
	}

	return $post_meta;
}

/**
 * Apply Filter for changing Attachment URL
 */
add_filter( 'stm_wp_import_attachment_url', 'stm_wp_import_attachment_url_filter', 10, 4 );

function stm_wp_import_attachment_url_filter( $url, $theme, $layout, $builder ) {
	if ( $builder === 'elementor' ) {
		$url = 'https://consulting.stylemixthemes.com/demo/wp-content/uploads/2016/06/placeholder.gif';
	}

	return $url;
}

/**
 * Add Action before Fetch Attachment
 */
add_action( 'stm_wp_import_before_fetch_attachment', 'stm_wp_import_before_fetch_attachment_action', 10, 1 );

function stm_wp_import_before_fetch_attachment_action( $builder ) {
	if ( function_exists('consulting_importer_get_placeholder') && $builder === 'elementor' ) {
		$placeholder = consulting_importer_get_placeholder();
		// Check if we have placeholder Already
		if ( $placeholder ) {
			return true;
		}
	}
}

/**
 * Add Action after Insert Attachment
 */
add_action( 'stm_wp_import_after_insert_attachment', 'stm_wp_import_after_insert_attachment_action', 10, 2 );

function stm_wp_import_after_insert_attachment_action( $post_id, $builder ) {
	if ( $builder === 'elementor' ) {
		update_post_meta( $post_id, '_wp_attachment_image_alt', 'theme_placeholder' );
	}
}

/**
 * Add Action after Import Post Meta
 */
add_action( 'stm_import_post_meta', 'stm_import_post_meta_action', 10, 3 );

function stm_import_post_meta_action( $post_id, $key, $value ) {
	$post_metas = [
		'stm_before',
		'stm_after',
	];

	if ( in_array( $key, $post_metas ) ) {
		update_post_meta($post_id, $key, $value);
	}
}

/**
 * Add Action for Mega Menu items
 */
add_action( 'stm_wp_import_update_nav_menu', 'stm_wp_import_update_nav_menu_action', 10, 2 );

function stm_wp_import_update_nav_menu_action( $post_meta, $post_id ) {
	$custom_args = [];

	foreach ( $post_meta as $key => $val ) {
		if ( ! empty( $val['value'] ) && strpos( $val['key'], '_stm') !== false ) {
			$custom_args[$val['key']] = $val['value'];
		}
	}

	if ( ! empty( $custom_args ) ) {
		foreach ( $custom_args as $key => $val ) {
			update_post_meta( $post_id, $key, $val );
		}
	}
}