<?php
add_filter( 'consulting_theme_options', function( $setups ) {

    $consulting_config = '';

    if( function_exists( 'consulting_config' ) ) {
        $consulting_config = consulting_config();
    }

    $fields = array(
        'footer_show_hide' => array(
            'label' => esc_html__( 'Hide Footer', 'consulting' ),
            'type' => 'checkbox',
            'value' => false,
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'footer_style' => array(
            'label' => esc_html__( 'Style', 'consulting' ),
            'description' => esc_html__( 'Select the footer layout', 'consulting' ),
            'type' => 'select',
            'options' => array(
                'style_1' => esc_html__( 'Style 1', 'consulting' ),
                'style_2' => esc_html__( 'Style 2', 'consulting' ),
                'style_3' => esc_html__( 'Style 3', 'consulting' )
            ),
            'value' => 'style_1',
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_show_hide',
                'value' => 'empty'
            )
        ),
        'footer_custom_settings' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Custom settings', 'consulting' ),
            'description' => esc_html__( 'Enable custom settings and select text, links and background options', 'consulting' ),
            'group' => 'started',
            'value' => false,
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_show_hide',
                'value' => 'empty'
            )
        ),
        'footer_custom_settings_color_text' => array(
            'type' => 'color',
            'label' => esc_html__( 'Text color', 'consulting' ),
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                array(
                    'key' => 'footer_custom_settings',
                    'value' => 'not_empty'
                ),
                array(
                    'key' => 'footer_show_hide',
                    'value' => 'empty'
                )
            ),
            'dependencies' => '&&'
        ),
        'footer_custom_settings_color_link' => array(
            'type' => 'color',
            'label' => esc_html__( 'Links color', 'consulting' ),
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_custom_settings',
                'value' => 'not_empty'
            )
        ),
        'footer_custom_settings_color_link_hover' => array(
            'type' => 'color',
            'label' => esc_html__( 'Links color on hover', 'consulting' ),
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_custom_settings',
                'value' => 'not_empty'
            )
        ),
        'footer_custom_settings_color_bg' => array(
            'type' => 'color',
            'label' => esc_html__( 'Background color', 'consulting' ),
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_custom_settings',
                'value' => 'not_empty'
            )
        ),
        'footer_custom_settings_bg_img' => array(
            'type' => 'image',
            'label' => esc_html__( 'Background image', 'consulting' ),
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_custom_settings',
                'value' => 'not_empty'
            )
        ),
        'footer_custom_settings_bg_overlay' => array(
            'type' => 'color',
            'label' => esc_html__( 'Background image overlay', 'consulting' ),
            'group' => 'ended',
            'submenu' => esc_html__( 'Main', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_custom_settings',
                'value' => 'not_empty'
            )
        ),
        'footer_logo_show_hide' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Hide Logo', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'footer_logo' => array(
            'type' => 'image',
            'label' => esc_html__( 'Logo', 'consulting' ),
            'submenu' => esc_html__( 'Logo', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_logo_show_hide',
                'value' => 'empty'
            )
        ),
        'footer_logo_width' => array(
            'type' => 'text',
            'label' => esc_html__( 'Width', 'consulting' ),
            'mode' => 'width',
            'units' => 'px',
            'output' => '#footer .widgets_row .footer_logo a img, #footer .footer-top .footer_logo a img',
            'submenu' => esc_html__( 'Logo', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_logo_show_hide',
                'value' => 'empty'
            )
        ),
        'footer_logo_height' => array(
            'type' => 'text',
            'label' => esc_html__( 'Height', 'consulting' ),
            'mode' => 'height',
            'units' => 'px',
            'output' => '#footer .widgets_row .footer_logo a img, #footer .footer-top .footer_logo a img',
            'submenu' => esc_html__( 'Logo', 'consulting' ),
            'dependency' => array(
                'key' => 'footer_logo_show_hide',
                'value' => 'empty'
            )
        ),
        'footer_show_hide_socials' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Hide Socials', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Socials', 'consulting' )
        ),
        'footer_socials_information_notice' => array(
            'description' => esc_html__( 'The social networks buttons will be displayed only if the links to these social networks are provided in the Socials tab', 'consulting' ),
            'type' => 'notice',
            'group' => 'started',
            'dependency' => array(
                'key' => 'footer_show_hide_socials',
                'value' => 'empty'
            ),
            'submenu' => esc_html__( 'Socials', 'consulting' )
        ),
        'footer_socials' => array(
            'type' => 'multi_checkbox',
            'label' => esc_html__( 'Socials Links', 'consulting' ),
            'options' => consulting_socials(),
            'group' => 'ended',
            'dependency' => array(
                'key' => 'footer_show_hide_socials',
                'value' => 'empty'
            ),
            'submenu' => esc_html__( 'Socials', 'consulting' )
        ),
        'footer_sidebar_count' => array(
            'type' => 'select',
            'label' => esc_html__( 'Additional Widgets Area', 'consulting' ),
            'description' => esc_html__( 'Specify the number of additional widgets for display', 'consulting' ),
            'value' => 4,
            'options' => array(
                'disable' => esc_html__( 'Disable', 'consulting' ),
                '1' => '1',
                '2' => '2',
                '3' => '3',
                '4' => '4'
            ),
            'submenu' => esc_html__( 'Widgets', 'consulting' )
        ),
        'footer_text' => array(
            'type' => 'textarea',
            'label' => esc_html__( 'Footer Text', 'consulting' ),
            'value' => '',
            'description' => esc_html__( 'This text will appear in the first widget area under footer logo', 'consulting' ),
            'submenu' => esc_html__( 'Widgets', 'consulting' )
        ),
        'footer_copyright' => array(
            'type' => 'textarea',
            'label' => esc_html__( 'Copyright', 'consulting' ),
            'value' => '',
            'submenu' => esc_html__( 'Widgets', 'consulting' )
        ),
        'footer_current_year' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Show current year', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Widgets', 'consulting' )
        )
    );

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_14' ) {
        $fields[ 'footer_enable_menu_top' ] = array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Show Menu', 'consulting' ),
            'value' => 'true',
            'submenu' => esc_html__( 'Main', 'consulting' )
        );
    }

    $customFields = array(
        'name' => esc_html__( 'Footer', 'consulting' ),
        'icon' => 'fas fa-digital-tachograph',
        'fields' => $fields
    );

    $setups[ 'footer' ] = $customFields;

    return $setups;

}, 10, 1 );