<?php
add_filter( 'consulting_theme_options', function( $setups ) {

    $consulting_config = '';
    $base_color = '';
    $secondary_color = '';
    $third_color = '';

    if( function_exists( 'consulting_config' ) ) {
        $consulting_config = consulting_config();

        if( !empty( $consulting_config[ 'base_color' ] ) ) {
            $base_color = $consulting_config[ 'base_color' ];
        }
        if( !empty( $consulting_config[ 'secondary_color' ] ) ) {
            $secondary_color = $consulting_config[ 'secondary_color' ];
        }
        if( !empty( $consulting_config[ 'third_color' ] ) ) {
            $third_color = $consulting_config[ 'third_color' ];
        }
    }

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_1' ) {
        $skin_arr = array(
            'skin_default' => esc_html__( 'Default', 'consulting' ),
            'skin_turquoise' => esc_html__( 'Turquoise', 'consulting' ),
            'skin_dark_denim' => esc_html__( 'Dark Denim', 'consulting' ),
            'skin_arctic_black' => esc_html__( 'Arctic and Black', 'consulting' ),
            'skin_custom' => esc_html__( 'Custom Colors', 'consulting' ),
        );
    } else {
        $skin_arr = array(
            'skin_default' => esc_html__( 'Default', 'consulting' ),
            'skin_custom' => esc_html__( 'Custom Colors', 'consulting' ),
        );
    }

    $fields = array(
        'logo' => array(
            'type' => 'image',
            'label' => esc_html__( 'Logo', 'consulting' ),
            'description' => sprintf( 'This logo appears on specific layouts. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/theme-customization#logo" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'group' => 'started',
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'dark_logo' => array(
            'type' => 'image',
            'label' => esc_html__( 'Dark logo', 'consulting' ),
            'description' => sprintf( 'This logo appears on specific layouts and on mobile header. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/theme-customization#logo" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'logo_width' => array(
            'type' => 'number',
            'label' => esc_html__( 'Logo width', 'consulting' ),
            'step' => 200,
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'logo_height' => array(
            'type' => 'number',
            'label' => esc_html__( 'Logo height', 'consulting' ),
            'step' => 200,
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'logo_margin' => array(
            'type' => 'spacing',
            'label' => esc_html__( 'Logo indent', 'consulting' ),
            'group' => 'ended',
            'units' => ['px', 'em'],
            'value' => [
                'top' => '0',
                'right' => '0',
                'bottom' => '0',
                'left' => '0',
                'unit' => 'px',
            ],
            'submenu' => esc_html__( 'Logo', 'consulting' )
        ),
        'enable_preloader' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Preloader', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'site_skin' => array(
            'type' => 'select',
            'label' => esc_html__( 'Skin', 'consulting' ),
            'description' => esc_html__( 'Select the skin color layout', 'consulting' ),
            'group' => 'started',
            'options' => $skin_arr,
            'value' => 'skin_default',
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'site_skin_base_color' => array(
            'type' => 'color',
            'label' => esc_html__( 'Custom Base Color', 'consulting' ),
            'value' => $base_color,
            'dependency' => array(
                'key' => 'site_skin',
                'value' => 'skin_custom'
            ),
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'site_skin_secondary_color' => array(
            'type' => 'color',
            'label' => esc_html__( 'Custom Secondary Color', 'consulting' ),
            'value' => $secondary_color,
            'dependency' => array(
                'key' => 'site_skin',
                'value' => 'skin_custom'
            ),
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'site_skin_third_color' => array(
            'type' => 'color',
            'label' => esc_html__( 'Custom Third Color', 'consulting' ),
            'group' => 'ended',
            'value' => $third_color,
            'dependency' => array(
                'key' => 'site_skin',
                'value' => 'skin_custom'
            ),
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'site_boxed' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Boxed Layout', 'consulting' ),
            'description' => esc_html__( 'Set the page layout as boxed and select the background from available options or upload your own', 'consulting' ),
            'group' => 'started',
            'value' => false,
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'bg_image' => array(
            'type' => 'image_select',
            'label' => esc_html__( 'Background Image', 'consulting' ),
            'width' => 100,
            'height' => 100,
            'options' => [
                'bg_img_1' => [
                    'alt'   => 'Image 1',
                    'img'   => get_template_directory_uri() . '/assets/images/bg/prev_img_1.png'
                ],
                'bg_img_2' => [
                    'alt'   => 'Image 2',
                    'img'   => get_template_directory_uri() . '/assets/images/bg/prev_img_2.png'
                ],
                'bg_img_3' => [
                    'alt'   => 'Image 3',
                    'img'   => get_template_directory_uri() . '/assets/images/bg/prev_img_3.png'
                ],
                'bg_img_4' => [
                    'alt'   => 'Image 4',
                    'img'   => get_template_directory_uri() . '/assets/images/bg/prev_img_4.png'
                ],
            ],
            'value' => 'bg_img_1',
            'dependency' => array(
                'key' => 'site_boxed',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'custom_bg_image' => array(
            'type' => 'image',
            'label' => esc_html__( 'Custom Background Image', 'consulting' ),
            'group' => 'ended',
            'dependency' => array(
                'key' => 'site_boxed',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        ),
        'google_api_key' => array(
            'type' => 'text',
            'label' => esc_html__( 'Google Maps API key', 'consulting' ),
            'description' => sprintf( 'Enable Google Maps Service. To obtain the keys please visit: <a href="https://cloud.google.com/maps-platform/" target="_blank" rel="nofollow">' . esc_html__( 'https://cloud.google.com/maps-platform/', 'consulting' ) . '</a>' ),
            'submenu' => esc_html__( 'Google API', 'consulting' )
        ),
        'enable_recaptcha' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Google Recaptcha API Settings', 'consulting' ),
            'description' => sprintf( 'Enable Google reCaptcha. To obtain the keys please visit: <a href="https://www.google.com/recaptcha/admin" target="_blank" rel="nofollow">' . esc_html__( 'https://www.google.com/recaptcha/admin', 'consulting' ) . '</a>' ),
            'group' => 'started',
            'submenu' => esc_html__( 'Google API', 'consulting' )
        ),
        'recaptcha_public_key' => array(
            'type' => 'text',
            'label' => esc_html__( 'Recaptcha Public key', 'consulting' ),
            'dependency' => array(
                'key' => 'enable_recaptcha',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Google API', 'consulting' )
        ),
        'recaptcha_secret_key' => array(
            'type' => 'text',
            'label' => esc_html__( 'Recaptcha Secret key', 'consulting' ),
            'group' => 'ended',
            'dependency' => array(
                'key' => 'enable_recaptcha',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Google API', 'consulting' )
        )
    );

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_melbourne' ) {
        $fields[ 'enable_black_and_white_images' ] = array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Black and White Images', 'consulting' ),
            'value' => 'true',
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        );
    }
    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_14' ) {
        $fields[ 'enable_page_switcher' ] = array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Page Scroll', 'consulting' ),
            'value' => 'true',
            'submenu' => esc_html__( 'Style Settings', 'consulting' )
        );
    }

    $customFields = array(
        'name' => esc_html__( 'General', 'consulting' ),
        'icon' => 'fas fa-sliders-h',
        'fields' => $fields
    );

    $setups[ 'general' ] = $customFields;

    return $setups;

}, 10, 1 );