<?php
add_filter( 'consulting_theme_options', function( $setups ) {

    $consulting_config = '';

    if( function_exists( 'consulting_config' ) ) {
        $consulting_config = consulting_config();
    }

    $fields = array(
        'top_bar_information_notice' => array(
            'type' => 'notice',
            'submenu' => esc_html__( 'Top Bar', 'consulting' ),
            'description' => esc_html__( 'This option will not be working if the WordPress Header Builder Plugin - Pearl is activated', 'consulting' )
        ),
        'top_bar' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Top Bar', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'wpml_switcher' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Enable Language Switcher', 'consulting' ),
            'description' => esc_html__( 'You need the WPML plugin to be installed', 'consulting' ),
            'group' => 'started',
            'value' => false,
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'wpml_switcher_style' => array(
            'type' => 'radio',
            'label' => esc_html__( 'Switcher Style', 'consulting' ),
            'description' => esc_html__( 'Select the style option for the switcher', 'consulting' ),
            'options' => array(
                'wpml_theme' => esc_html__( 'Theme', 'consulting' ),
                'wpml_default' => esc_html__( 'value (WPML)', 'consulting' )
            ),
            'value' => 'wpml_theme',
            'dependency' => array(
                'key' => 'wpml_switcher',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'wpml_switcher_mobile' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Show Language Switcher on mobile', 'consulting' ),
            'group' => 'ended',
            'value' => false,
            'dependency' => array(
                'key' => 'wpml_switcher',
                'value' => 'not_empty'
            ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'wc_topbar_cart_hide' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Disable WooCommerce Cart', 'consulting' ),
            'value' => false,
            'description' => sprintf( 'This option can be enabled for the specific header style in a particular layout. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/header#woocommerce-cart" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'offices_contact' => array(
            'type' => 'repeater',
            'label' => esc_html__( 'Office', 'consulting' ),
            'description' => esc_html__( 'Set up the display of the office address, working hours, and phone number', 'consulting' ),
            'fields' => array(
                'top_bar_contact_office' => array(
                    'type' => 'text',
                    'label' => esc_html__( 'Name', 'consulting' ),
                    'value' => ''
                ),
                'top_bar_contact_address' => array(
                    'type' => 'text',
                    'label' => esc_html__( 'Address', 'consulting' ),
                    'value' => ''
                ),
                'top_bar_contact_address_icon' => array(
                    'type' => 'icon_picker',
                    'label' => esc_html__( 'Address Icon', 'consulting' ),
                    'value' => 'fa-map-marker'
                ),
                'top_bar_contact_email' => array(
                    'type' => 'text',
                    'label' => esc_html__( 'Email', 'consulting' ),
                    'value' => ''
                ),
                'top_bar_contact_email_icon' => array(
                    'type' => 'icon_picker',
                    'label' => esc_html__( 'Email Icon', 'consulting' ),
                    'value' => 'fa-envelope'
                ),
                'top_bar_contact_hours' => array(
                    'type' => 'text',
                    'label' => esc_html__( 'Working Hours', 'consulting' ),
                    'value' => ''
                ),
                'top_bar_contact_hours_icon' => array(
                    'type' => 'icon_picker',
                    'label' => esc_html__( 'Hours Icon', 'consulting' ),
                    'value' => 'fa-map-marker'
                ),
                'top_bar_contact_phone' => array(
                    'type' => 'text',
                    'label' => esc_html__( 'Phone Number', 'consulting' ),
                    'value' => ''
                ),
                'top_bar_contact_phone_icon' => array(
                    'type' => 'icon_picker',
                    'label' => esc_html__( 'Phone Icon', 'consulting' ),
                    'value' => 'fa-map-marker'
                )
            ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        ),
        'header_style_information_notice' => array(
            'description' => esc_html__( 'This option will not be working if the WordPress Header Builder Plugin - Pearl is activated', 'consulting' ),
            'type' => 'notice',
            'submenu' => esc_html__( 'Main', 'consulting' ),
        ),
        'header_style' => array(
            'type' => 'select',
            'label' => esc_html__( 'Header Style', 'consulting' ),
            'options' => array(
                'header_style_1' => esc_html__( 'Style 1', 'consulting' ),
                'header_style_2' => esc_html__( 'Style 2', 'consulting' ),
                'header_style_3' => esc_html__( 'Style 3', 'consulting' ),
                'header_style_4' => esc_html__( 'Style 4', 'consulting' ),
                'header_style_5' => esc_html__( 'Style 5', 'consulting' ),
                'header_style_6' => esc_html__( 'Style 6', 'consulting' ),
                'header_style_7' => esc_html__( 'Style 7', 'consulting' ),
                'header_style_8' => esc_html__( 'Style 8', 'consulting' ),
            ),
            'value' => 'header_style_1',
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'mega_menu' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Mega Menu', 'consulting' ),
            'description' => esc_html__( 'Enable the display of mega menu', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'sticky_menu' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Sticky Menu', 'consulting' ),
            'description' => esc_html__( 'Enable Sticky menu', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'wc_cart_hide' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'WooCommerce Cart', 'consulting' ),
            'description' => sprintf( 'You need to install and set up the WooCommerce plugin. This option can be enabled for the specific header style in a particular layout. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/header#woocommerce-cart-1" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'value' => false,
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'mobile_grid' => array(
            'type' => 'radio',
            'label' => esc_html__( 'Mobile Header Breakpoint', 'consulting' ),
            'description' => esc_html__( 'Select the mobile header breakpoint (Landscape - 1024px resolution, Portrait 991px resolution).', 'consulting' ),
            'options' => array(
                'landscape' => esc_html__( 'Tablet Landscape', 'consulting' ),
                'portrait' => esc_html__( 'Tablet Portrait', 'consulting' )
            ),
            'value' => 'landscape',
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'header_copyright' => array(
            'type'    => 'textarea',
            'label'   => esc_html__( 'Copyright', 'consulting' ),
            'value'   => '',
            'description' => sprintf( 'This option can be enabled for the specific header style. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/header#copyright" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'submenu' => esc_html__( 'Main', 'consulting' )
        ),
        'header_information_notice' => array(
            'description' => sprintf( 'This option can be enabled for the specific header style. <a href="https://docs.stylemixthemes.com/consulting-theme-documentation/theme-options/header#information" target="_blank" rel="nofollow">' . esc_html__( 'See more details ', 'consulting' ) . '</a>' ),
            'type' => 'notice',
            'submenu' => esc_html__( 'Information', 'consulting' ),
        ),
        'header_address' => array(
            'type' => 'textarea',
            'label' => esc_html__( 'Address', 'consulting' ),
            'value' => '',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'header_address_icon' => array(
            'type' => 'icon_picker',
            'label' => esc_html__( 'Address Icon', 'consulting' ),
            'value' => 'stm-pin_13',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'header_working_hours' => array(
            'type' => 'textarea',
            'label' => esc_html__( 'Working Hours', 'consulting' ),
            'value' => '',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'header_working_hours_icon' => array(
            'type' => 'icon_picker',
            'label' => esc_html__( 'Working Hours Icon', 'consulting' ),
            'value' => 'stm-mail_13',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'header_phone' => array(
            'type' => 'textarea',
            'label' => esc_html__( 'Phone number', 'consulting' ),
            'value' => '',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'header_phone_icon' => array(
            'type' => 'icon_picker',
            'label' => esc_html__( 'Phone number Icon', 'consulting' ),
            'value' => 'stm-phone_13',
            'submenu' => esc_html__( 'Information', 'consulting' )
        ),
        'socials_information_notice' => array(
            'description' => esc_html__( 'This option will not be working if the WordPress Header Builder Plugin - Pearl is activated', 'consulting' ),
            'type' => 'notice',
            'submenu' => esc_html__( 'Socials', 'consulting' ),
        ),
        'mobile_socials_show_hide' => array(
            'type' => 'checkbox',
            'label' => esc_html__( 'Show on mobile', 'consulting' ),
            'description' => esc_html__( 'Enable the display of socials on mobile', 'consulting' ),
            'value' => false,
            'submenu' => esc_html__( 'Socials', 'consulting' )
        ),
        'header_socials_information_notice' => array(
            'description' => esc_html__( 'The social networks buttons will be displayed only if the links to these social networks are provided in the Socials tab', 'consulting' ),
            'type' => 'notice',
            'group' => 'started',
            'submenu' => esc_html__( 'Socials', 'consulting' )
        ),
        'header_socials' => array(
            'type' => 'multi_checkbox',
            'label' => esc_html__( 'Socials Links', 'consulting' ),
            'description' => esc_html__( 'Select what social networks to display', 'consulting' ),
            'options' => consulting_socials(),
            'group' => 'ended',
            'submenu' => esc_html__( 'Socials', 'consulting' )
        )
    );

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_18' ) {
        $fields[ 'header_l18_btn_text' ] = array(
            'type' => 'text',
            'group' => 'started',
            'label' => esc_html__( 'Button label', 'consulting' ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields[ 'header_l18_btn_link' ] = array(
            'type' => 'text',
            'group' => 'ended',
            'label' => esc_html__( 'Button link', 'consulting' ),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
    }

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_13' || !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_barcelona' ) {
        $fields[ 'top_bar_style' ] = array(
            'type' => 'select',
            'group' => 'started',
            'label' => esc_html__( 'Top Bar Style', 'consulting' ),
            'options' => array(
                'style_1' => esc_html__( 'Style 1', 'consulting' ),
                'style_2' => esc_html__( 'Style 2', 'consulting' ),
            ),
            'value' => 'style_1',
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields[ 'stm_work_hours_l13' ] = array(
            'type' => 'text',
            'label' => esc_html__( 'Working Hours', 'consulting' ),
            'value' => '',
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields[ 'stm_work_hours_l13_icon' ] = array(
            'type' => 'icon_picker',
            'label' => esc_html__( 'Hours Icon', 'consulting' ),
            'value' => 'fa fa-clock-o',
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields[ 'top_bar_search_l13' ] = array(
            'type' => 'checkbox',
            'group' => 'ended',
            'label' => esc_html__( 'Enable Search', 'consulting' ),
            'value' => 'true',
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields[ 'top_bar_socials_l13' ] = array(
            'type' => 'multi_checkbox',
            'label' => esc_html__( 'Socials Links', 'consulting' ),
            'options' => consulting_socials(),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
    }

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_16' ) {
        $fields[ 'top_bar_socials_l13' ] = array(
            'type' => 'multi_checkbox',
            'group' => 'started',
            'label' => esc_html__( 'Socials Links', 'consulting' ),
            'options' => consulting_socials(),
            'submenu' => esc_html__( 'Top Bar', 'consulting' )
        );
        $fields['header_l16_btn_text'] = array(
            'type'    => 'text',
            'label'   => esc_html__( 'Button label', 'consulting' ),
            'submenu' => esc_html__( 'Information', 'consulting' )
        );
        $fields['header_l16_btn_link'] = array(
            'type'    => 'text',
            'group' => 'ended',
            'label'   => esc_html__( 'Button link', 'consulting' ),
            'submenu' => esc_html__( 'Information', 'consulting' )
        );
    }

    if( !empty( $consulting_config[ 'layout' ] ) && $consulting_config[ 'layout' ] == 'layout_14' ) {
        $args = array( 'post_type' => 'wpcf7_contact_form', 'posts_per_page' => -1 );
        $forms = array(
            'none' => esc_html__( 'Choose contact form', 'consulting' ),
        );
        if( $cf7Forms = get_posts( $args ) ) {
            foreach ( $cf7Forms as $cf7Form ) {
                $forms[ $cf7Form->ID ] = $cf7Form->post_title;
            };
        }
        $fields[ 'header_popup' ] = array(
            'type' => 'select',
            'label' => esc_html__( 'Contact form (Popup)', 'consulting' ),
            'value' => 'none',
            'options' => $forms,
            'submenu' => esc_html__( 'Information', 'consulting' )
        );
    }

    $customFields = array(
        'name' => esc_html__( 'Header', 'consulting' ),
        'icon' => 'fas fa-ellipsis-v',
        'fields' => $fields
    );

    $setups[ 'header' ] = $customFields;

    return $setups;

}, 10, 1 );